{ pkgs, config, lib, ... }:

let
  unstable = (import ../../unstable.nix config);
in {
  environment = {
    systemPackages = with pkgs; [
      arc-theme
      gnomeExtensions.appindicator
      gnomeExtensions.caffeine
      gnomeExtensions.gnome-40-ui-improvements
      gnomeExtensionsCustom.notification-timeout # Custom package
      gnome.eog
      gnome.nautilus
      unstable.gnome.gnome-shell
      gnome.gnome-terminal
      pinentry-gnome
      dconf # For home-manager
    ];
    gnome.excludePackages = pkgs.gnome.optionalPackages;
  };

  services = {
    accounts-daemon.enable = true;
    colord.enable = false;
    geoclue2.enable = false;
    dleyna-renderer.enable = false;
    dleyna-server.enable = false;
    gvfs.enable = lib.mkForce false;
    telepathy.enable = false;
    gnome = {
      chrome-gnome-shell.enable = false;
      gnome-initial-setup.enable = false;
      gnome-remote-desktop.enable = false;
      rygel.enable = false;
      gnome-online-accounts.enable = false;
      evolution-data-server.enable = lib.mkForce false;
      tracker.enable = false;
      tracker-miners.enable = false;
      core-utilities.enable = false;
      games.enable = false;
    };

    udev.packages = with pkgs; [ gnome.gnome-settings-daemon ];
    
    xserver = {
      enable = true;
      layout = "de";

      libinput.enable = true;
      
      desktopManager.gnome.enable = true;
      displayManager = {
        gdm.enable = true;
        gdm.wayland = true;
      };
    };
  };

  xdg.portal = {
    enable = true;
    extraPortals = [ pkgs.xdg-desktop-portal-gtk ];
    gtkUsePortal = true;
  };
}
