{ pkgs, config, ... }:

{
  config = {
    users.users.alexander = {
	    isNormalUser = true;
	    extraGroups = [ "wheel" "audio" "video" "kvm" "input" "libvirtd" ];
	    hashedPassword = "$5$i4aZuQ/WXP.rFOc$lCzDqbrVsqBQt5954O.3bFPknD0jn27MmqzmE4DIAEC";
      shell = pkgs.zsh;
      useDefaultShell = false;
      uid = 1000;
      isSystemUser = false;
    };

    # Activate gpg
    programs.gnupg.agent.enable = true;
    
    home-manager.users.alexander = {
      pam.sessionVariables = {
        NIXOS_CONFIG = "\${HOME}/Development/Personal/nixos-config/${config.networking.hostName}.nix";
      };
      programs.home-manager.enable = true;

      programs.ssh = {
        enable = true;
        extraConfig = ''
          IdentityFile ~/.ssh/gitea_papatutuwawa

          Host git.polynom.me
              HostName git.polynom.me
              User git
              IdentityFile ~/.ssh/gitea_papatutuwawa
        '';
      };
      
      services.gpg-agent = {
        enable = true;
        pinentryFlavor = "gnome3";
      };
      
      dconf.settings = {
        # The packages come in from modules/programs/gnome
        # Theme
        "org/gnome/desktop/interface" = {
          gtk-theme = "Arc-Dark";
        };

        # Nightlight (TODO: ?)
        "org/gnome/settings-daemon/plugins/color" = {
          night-light-enabled = true;
        };
        
        # Extensions
        "org/gnome/shell" = {
          enabled-extensions = [
            "caffeine@patapon.info"
            "notification-timeout@chlumskyvaclav.gmail.com"
          ];
        };

        "org/gnome/shell/extensions/caffeine" = {
          show-notifications = false;
          inhibit-apps = [ "mpv.desktop" ];
        };
        "org/gnome/shell/extensions/notification-timeout" = {
          timeout = 3000;
        };
      };
    };    
  };
}
